@@ -9,7 +9,7 @@ the GOES/XRS instrument, see [Ref1]_.  GOES/XRS has become
 the "standard candle" for solar coronal observations due its longevity and
 consistency.  The GOES event list, based on GOES/XRS observations, has
 become the standard solar flare catalogue.
-See http://www.ngdc.noaa.gov/stp/solar/solarflares.html for information
+See https://www.ngdc.noaa.gov/stp/solar/solarflares.html for information
 on the GOES event list definitions and data.
 
 The functions in this module provide useful software to analyse GOES/XRS
@@ -41,7 +41,7 @@ References
 ----------
 
 .. [Ref1] Hanser, F.A., & Sellers, F.B. 1996, Proc. SPIE, 2812, 344
-.. [Ref2] Dere, K.P., et al. 2009 A&A, 498, 915 DOI: `10.1051/0004-6361/200911712 <https://dx.doi.org/10.1051/0004-6361/200911712>`__
+.. [Ref2] Dere, K.P., et al. 2009 A&A, 498, 915 DOI: `10.1051/0004-6361/200911712 <https://doi.org/10.1051/0004-6361/200911712>`__
 
 """
 
@@ -368,9 +368,9 @@ def _goes_chianti_tem(longflux, shortflux, satellite=8,
     ...                              date='2014-04-16',
     ...                              abundances="coronal")  # doctest: +REMOTE_DATA
     >>> temp  # doctest: +REMOTE_DATA
-    <Quantity [ 11.28295376, 11.28295376] MK>
+    <Quantity [11.28295376, 11.28295376] MK>
     >>> em  # doctest: +REMOTE_DATA
-    <Quantity [  4.78577516e+48,  4.78577516e+48] 1 / cm3>
+    <Quantity [4.78577516e+48, 4.78577516e+48] 1 / cm3>
 
     """
     if not download_dir:
@@ -506,7 +506,7 @@ def _goes_get_chianti_temp(fluxratio, satellite=8, abundances="coronal",
     >>> temp = _goes_get_chianti_temp(fluxratio, satellite=15,
     ...                               abundances="coronal")  # doctest: +REMOTE_DATA
     >>> temp  # doctest: +REMOTE_DATA
-    <Quantity [ 12.27557778, 12.27557778] MK>
+    <Quantity [12.27557778, 12.27557778] MK>
 
     """
     if not download_dir:
@@ -662,7 +662,7 @@ def _goes_get_chianti_em(longflux, temp, satellite=8, abundances="coronal",
     >>> em = _goes_get_chianti_em(longflux, temp, satellite=15,
     ...                           abundances="coronal")  # doctest: +REMOTE_DATA
     >>> em  # doctest: +REMOTE_DATA
-    <Quantity [  3.45200672e+48,  3.45200672e+48] 1 / cm3>
+    <Quantity [3.45200672e+48, 3.45200672e+48] 1 / cm3>
 
     """
     if not download_dir:
@@ -814,7 +814,7 @@ def calculate_radiative_loss_rate(goeslc, force_download=False,
     2014-01-01 00:00:06.564999  9.298800e-08  0.000004
 
     >>> goeslc_new = calculate_radiative_loss_rate(goeslc)  # doctest: +REMOTE_DATA
-    >>> goeslc_new.data   # doctest: +NORMALIZE_WHITESPACE +REMOTE_DATA
+    >>> goeslc_new.data   # doctest:  +REMOTE_DATA
                                         xrsa      xrsb  temperature            em  \\
     2014-01-01 00:00:00.421999  9.187300e-08  0.000004     6.270239  6.440648e+48
     2014-01-01 00:00:02.468999  9.187300e-08  0.000004     6.270239  6.440648e+48
@@ -942,7 +942,7 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
     >>> em = Quantity([4.0e+48, 4.0e+48], unit="cm**(-3)")
     >>> rad_loss = _calc_rad_loss(temp, em)  # doctest: +REMOTE_DATA
     >>> rad_loss["rad_loss_rate"]  # doctest: +REMOTE_DATA
-    <Quantity [  3.01851392e+19,  3.01851392e+19] J / s>
+    <Quantity [3.01851392e+19, 3.01851392e+19] J / s>
     """
     if not download_dir:
         download_dir = get_and_create_download_dir()
@@ -1073,7 +1073,7 @@ def calculate_xray_luminosity(goeslc):
     2014-01-01 00:00:06.564999  9.298800e-08  0.000004
 
     >>> goeslc_new = calculate_xray_luminosity(goeslc)  # doctest: +REMOTE_DATA
-    >>> goeslc_new.data   # doctest: +NORMALIZE_WHITESPACE +REMOTE_DATA
+    >>> goeslc_new.data   # doctest:  +REMOTE_DATA
                                         xrsa      xrsb  luminosity_xrsa  \\
     2014-01-01 00:00:00.421999  9.187300e-08  0.000004     2.498454e+16
     2014-01-01 00:00:02.468999  9.187300e-08  0.000004     2.498454e+16
@@ -1171,15 +1171,15 @@ def _goes_lx(longflux, shortflux, obstime=None, date=None):
     ...                     datetime(2014,1,1,0,0,10),], dtype=object)
     >>> lx_out = _goes_lx(longflux, shortflux, obstime)  # doctest: +REMOTE_DATA
     >>> lx_out["longlum"]  # doctest: +REMOTE_DATA
-    <Quantity [  1.96860565e+18,  1.96860565e+18,  1.96860565e+18,
-                 1.96860565e+18,  1.96860565e+18,  1.96860565e+18] W>
+    <Quantity [1.96860565e+18, 1.96860565e+18, 1.96860565e+18, 1.96860565e+18,
+                 1.96860565e+18, 1.96860565e+18] W>
     >>> lx_out["shortlum"]  # doctest: +REMOTE_DATA
-    <Quantity [  1.96860565e+17,  1.96860565e+17,  1.96860565e+17,
-                 1.96860565e+17,  1.96860565e+17,  1.96860565e+17] W>
+    <Quantity [1.96860565e+17, 1.96860565e+17, 1.96860565e+17, 1.96860565e+17,
+               1.96860565e+17, 1.96860565e+17] W>
     >>> lx_out["longlum_int"]  # doctest: +REMOTE_DATA
-    <Quantity 1.968605654118636e+19 s W>
+    <Quantity 1.96860565e+19 s W>
     >>> lx_out["shortlum_int"]  # doctest: +REMOTE_DATA
-    <Quantity 1.9686056541186358e+18 s W>
+    <Quantity 1.96860565e+18 s W>
 
     """
     # Calculate X-ray luminosities
@@ -1266,7 +1266,7 @@ def _calc_xraylum(flux, date=None):
     >>> flux = Quantity([7e-6,7e-6], unit="W/m**2")
     >>> xraylum = _calc_xraylum(flux, date="2014-04-21")  # doctest: +REMOTE_DATA
     >>> xraylum  # doctest: +REMOTE_DATA
-    <Quantity [  1.98751663e+18,  1.98751663e+18] W>
+    <Quantity [1.98751663e+18, 1.98751663e+18] W>
 
     """
     if date is not None:
