@@ -9,8 +9,7 @@ FITS
     sunpy header. To add a comment to the file on write, add a comment to this
     dictionary with the same name as a key in the header (upcased).
 
-PyFITS
-    [1] Due to the way PyFITS works with images the header dictionary may
+    [2] Due to the way `~astropy.io.fits` works with images the header dictionary may
     differ depending on whether is accessed before or after the fits[0].data
     is requested. If the header is read before the data then the original
     header will be returned. If the header is read after the data has been
@@ -18,7 +17,7 @@ PyFITS
     reflecting these changes will be returned: BITPIX may differ and
     BSCALE and B_ZERO may be dropped in the modified version.
 
-    [2] The verify('fix') call attempts to handle violations of the FITS
+    [3] The verify('fix') call attempts to handle violations of the FITS
     standard. For example, nan values will be converted to "nan" strings.
     Attempting to cast a pyfits header to a dictionary while it contains
     invalid header tags will result in an error so verifying it early on
@@ -26,9 +25,7 @@ PyFITS
 
 References
 ----------
-| http://stackoverflow.com/questions/456672/class-factory-in-python
-| http://stsdas.stsci.edu/download/wikidocs/The_PyFITS_Handbook.pdf
-
+| https://stackoverflow.com/questions/456672/class-factory-in-python
 """
 from __future__ import absolute_import, division, print_function
 import os
@@ -181,7 +178,7 @@ def write(fname, data, header, **kwargs):
     # Check Header
     key_comments = header.pop('KEYCOMMENTS', False)
 
-    for k,v in header.items():
+    for k, v in header.items():
         if isinstance(v, fits.header._HeaderCommentaryCards):
             if k == 'comments':
                 comments = str(v).split('\n')
@@ -198,15 +195,19 @@ def write(fname, data, header, **kwargs):
             fits_header.append(fits.Card(k, v))
 
     if isinstance(key_comments, dict):
-        for k,v in key_comments.items():
-            fits_header.comments[k] = v
+        for k, v in key_comments.items():
+            # Check that the Card for the comment exists before trying to write to it.
+            if k in fits_header:
+                fits_header.comments[k] = v
     elif key_comments:
         raise TypeError("KEYCOMMENTS must be a dictionary")
 
-    fitskwargs = {'output_verify':'fix'}
+    if isinstance(fname, str):
+        fname = os.path.expanduser(fname)
+
+    fitskwargs = {'output_verify': 'fix'}
     fitskwargs.update(kwargs)
-    fits.writeto(os.path.expanduser(fname), data, header=fits_header,
-                   **fitskwargs)
+    fits.writeto(fname, data, header=fits_header, **fitskwargs)
 
 
 def extract_waveunit(header):
