@@ -81,3 +81,18 @@ def test_extract_waveunit_wavelnthcomment_parentheses():
     # WAVELNTH comment is: "Observed wavelength (nm)"
     waveunit = extract_waveunit(get_header(SVSM_IMAGE)[0])
     assert waveunit == 'nm'
+
+
+def test_simple_write(tmpdir):
+    data, header = sunpy.io.fits.read(AIA_171_IMAGE)[0]
+    outfile = tmpdir / "test.fits"
+    sunpy.io.fits.write(str(outfile), data, header)
+    assert outfile.exists()
+
+
+def test_extra_comment_write(tmpdir):
+    data, header = sunpy.io.fits.read(AIA_171_IMAGE)[0]
+    header["KEYCOMMENTS"]["TEST"] = "Hello world"
+    outfile = tmpdir / "test.fits"
+    sunpy.io.fits.write(str(outfile), data, header)
+    assert outfile.exists()
