@@ -1,11 +1,13 @@
 """SOHO Map subclass definitions"""
 from __future__ import absolute_import, print_function, division
-#pylint: disable=W0221,W0222,E1101,E1121
+
+# pylint: disable=W0221,W0222,E1101,E1121
 
 __author__ = "Keith Hughitt"
 __email__ = "keith.hughitt@nasa.gov"
 
 import numpy as np
+import matplotlib.pyplot as plt
 from matplotlib import colors
 
 from astropy.units import Quantity
@@ -15,7 +17,6 @@ from astropy.visualization.mpl_normalize import ImageNormalize
 from sunpy.map import GenericMap
 from sunpy.sun import constants
 from sunpy.sun import sun
-from sunpy.cm import cm
 from sunpy.map.sources.source_type import source_stretch
 from sunpy.coordinates import get_sunearth_distance
 
@@ -55,13 +56,12 @@ class EITMap(GenericMap):
 
     References
     ----------
-    * `SOHO Mission Page <http://sohowww.nascom.nasa.gov>`_
-    * `SOHO EIT Instrument Page <http://umbra.nascom.nasa.gov/eit/>`_
-    * `SOHO EIT User Guide <http://umbra.nascom.nasa.gov/eit/eit_guide/>`_
+    * `SOHO Mission Page <https://sohowww.nascom.nasa.gov/>`_
+    * `SOHO EIT Instrument Page <https://umbra.nascom.nasa.gov/eit/>`_
+    * `SOHO EIT User Guide <https://umbra.nascom.nasa.gov/eit/eit_guide/>`_
     """
 
     def __init__(self, data, header, **kwargs):
-
         GenericMap.__init__(self, data, header, **kwargs)
 
         # Fill in some missing info
@@ -69,7 +69,7 @@ class EITMap(GenericMap):
         self.meta['waveunit'] = "Angstrom"
         self._fix_dsun()
         self._nickname = self.detector
-        self.plot_settings['cmap'] = cm.get_cmap(self._get_cmap_name())
+        self.plot_settings['cmap'] = plt.get_cmap(self._get_cmap_name())
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.5)))
 
     @property
@@ -103,10 +103,7 @@ class LASCOMap(GenericMap):
 
     References
     ----------
-    * `SOHO Mission Page <http://sohowww.nascom.nasa.gov>`_
-    * `SOHO LASCO Instrument Page <http://lasco-www.nrl.navy.mil>`_
-    * `SOHO LASCO Fits Header keywords <http://lasco-www.nrl.navy.mil/index.php?p=content/keywords>`_
-    * `SOHO LASCO User Guide <http://lasco-www.nrl.navy.mil/index.php?p=content/handbook/hndbk>`_
+    * `SOHO Mission Page <https://sohowww.nascom.nasa.gov/>`_
     """
 
     def __init__(self, data, header, **kwargs):
@@ -117,22 +114,22 @@ class LASCOMap(GenericMap):
         self.meta['CUNIT2'] = self.meta['CUNIT2'].lower()
 
         # Fill in some missing or broken info
-        datestr = "{date}T{time}".format(date=self.meta.get('date-obs',
-                                                            self.meta.get('date_obs')
-                                                            ),
-                                         time=self.meta.get('time-obs',
-                                                            self.meta.get('time_obs')
-                                                            )
-                                         )
-        self.meta['date-obs'] = datestr
+        # Test if change has already been applied
+        if 'T' not in self.meta['date-obs']:
+            datestr = "{date}T{time}".format(date=self.meta.get('date-obs',
+                                                                self.meta.get('date_obs')
+                                                                ),
+                                             time=self.meta.get('time-obs',
+                                                                self.meta.get('time_obs')
+                                                                )
+                                             )
+            self.meta['date-obs'] = datestr
 
         # If non-standard Keyword is present, correct it too, for compatibility.
         if 'date_obs' in self.meta:
             self.meta['date_obs'] = self.meta['date-obs']
-        self.meta['wavelnth'] = np.nan
-        self.meta['waveunit'] = 'nm'
         self._nickname = self.instrument + "-" + self.detector
-        self.plot_settings['cmap'] = cm.get_cmap('soholasco{det!s}'.format(det=self.detector[1]))
+        self.plot_settings['cmap'] = plt.get_cmap('soholasco{det!s}'.format(det=self.detector[1]))
         self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, PowerStretch(0.5)))
 
     @property
@@ -168,10 +165,10 @@ class MDIMap(GenericMap):
 
     References
     ----------
-    * `SOHO Mission Page <http://sohowww.nascom.nasa.gov>`_
+    * `SOHO Mission Page <https://sohowww.nascom.nasa.gov/>`_
     * `SOHO MDI Instrument Page <http://soi.stanford.edu>`_
     * `SOHO MDI Fits Header keywords <http://soi.stanford.edu/sssc/doc/keywords.html>`_
-    * `SOHO MDI Instrument Paper <http://soi.stanford.edu/sssc/doc/SP_paper_1995/MDI_SP_paper_1995.pdf>`_
+    * `SOHO MDI Instrument Paper <https://doi.org/10.1007/978-94-009-0191-9_5>`_
     """
 
     def __init__(self, data, header, **kwargs):
@@ -181,8 +178,6 @@ class MDIMap(GenericMap):
         # Fill in some missing or broken info
         self.meta['detector'] = "MDI"
         self._fix_dsun()
-        self.meta['wavelnth'] = np.nan
-        self.meta['waveunit'] = 'nm'
         self._nickname = self.detector + " " + self.measurement
         vmin = np.nanmin(self.data)
         vmax = np.nanmax(self.data)
