@@ -36,19 +36,19 @@ class XRSTimeSeries(GenericTimeSeries):
     Examples
     --------
     >>> import sunpy.timeseries
-    >>> import sunpy.data.sample
-    >>> goes = sunpy.timeseries.TimeSeries(sunpy.data.sample.GOES_XRS_TIMESERIES)
+    >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
+    >>> goes = sunpy.timeseries.TimeSeries(sunpy.data.sample.GOES_XRS_TIMESERIES)  # doctest: +REMOTE_DATA
     >>> goes.peek()   # doctest: +SKIP
 
     References
     ----------
     * `GOES Mission Homepage <http://www.goes.noaa.gov>`_
-    * `GOES XRS Homepage <http://www.swpc.noaa.gov/products/goes-x-ray-flux>`_
-    * `GOES XRS Guide <http://ngdc.noaa.gov/stp/satellite/goes/doc/GOES_XRS_readme.pdf>`_
-    * `NASCOM Data Archive <http://umbra.nascom.nasa.gov/goes/fits/>`_
+    * `GOES XRS Homepage <https://www.swpc.noaa.gov/products/goes-x-ray-flux>`_
+    * `GOES XRS Guide <https://ngdc.noaa.gov/stp/satellite/goes/doc/GOES_XRS_readme.pdf>`_
+    * `NASCOM Data Archive <https://umbra.nascom.nasa.gov/goes/fits/>`_
 
     Notes:
-    http://umbra.nascom.nasa.gov/goes/fits/goes_fits_files_notes.txt
+    https://umbra.nascom.nasa.gov/goes/fits/goes_fits_files_notes.txt
     """
 
     # Class attribute used to specify the source class of the TimeSeries.
@@ -72,11 +72,6 @@ class XRSTimeSeries(GenericTimeSeries):
 
         **kwargs : `dict`
             Any additional plot arguments that should be used when plotting.
-
-        Returns
-        -------
-        fig : `~matplotlib.Figure`
-            A plot figure.
         """
         # Check we have a timeseries valid for plotting
         self._validate_data_for_ploting()
@@ -115,8 +110,6 @@ class XRSTimeSeries(GenericTimeSeries):
         figure.autofmt_xdate()
         figure.show()
 
-        return figure
-
     # ToDo: is this part of the DL pipeline? If so delete.
     @classmethod
     def _get_goes_sat_num(self, start, end):
@@ -154,7 +147,7 @@ class XRSTimeSeries(GenericTimeSeries):
     @classmethod
     def _parse_file(cls, filepath):
         """Parses a GOES/XRS FITS file from
-        http://umbra.nascom.nasa.gov/goes/fits/"""
+        https://umbra.nascom.nasa.gov/goes/fits/"""
 
         hdus = sunpy.io.read_file(filepath)
         return cls._parse_hdus(hdus)
