@@ -204,7 +204,7 @@ def expand_list(inp):
 
     References
     ----------
-    Taken from :http://stackoverflow.com/a/2185971/2486799
+    Taken from :https://stackoverflow.com/questions/2185822/expanding-elements-in-a-list/2185971#2185971
 
     """
     return [item for item in expand_list_generator(inp)]
